/* $Id: buttons.h 11 2009-10-14 06:21:07Z andreas $ */

/*
 * Copyright (c) 2006-2009 Andreas Schroeder <andreas@a-netz.de>
 *
 * Implement functions of an infrared remote control and RC5 protocol with an
 * Atmel AVR controller.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/**
 * @file
 * The buttons module contains functions to read out the currently pressed 
 * buttons and convert the key press event to a RC5 command code.
 */

#ifndef BUTTONS_H
#define BUTTONS_H

#include <avr/io.h>

#include "rc5.h"

/** Enable the external interrupt to detect button presses. */
#define ENABLE_BUTTONS() (GIMSK |= _BV(INT0))

/** Disable the external interrupt to detect button presses. */
#define DISABLE_BUTTONS() (GIMSK &= ~_BV(INT0))

/**
 * Initialize the hardware for accessing the buttons.
 */
void buttons_init(void);

/**
 * Reads in the button state and determines the RC5 command code to be sent.
 *
 * @param cmd This is filled with the RC5 command code if a valid key press 
 * has been detected.
 * @return 0 if a button has been pressed and a valid rc5 command code has
 * been written to cmd, 1 if not.
 */
uint8_t rc5_get_cmd(rc5_cmd_t *cmd);

#endif // BUTTONS_H