/* $Id: rc5.h 11 2009-10-14 06:21:07Z andreas $ */

/*
 * Copyright (c) 2006-2009 Andreas Schroeder <andreas@a-netz.de>
 *
 * Implement functions of an infrared remote control and RC5 protocol with an
 * Atmel AVR controller.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/**
 * @file
 * The rc5 module contains the code to generate RC5 telegrams. It uses the 
 * timer 1 compare interrupt to generate the half-bit clock and the waveform 
 * generation capabilities of the AVR to generate the 36kHz signal modulation.
 */

#ifndef RC5_H
#define RC5_H

#include <stdint.h>

/**
 * This datatype is used to represent a rc5 command code. This is not the 
 * complete telegram, but only the command section (excluding start bits and
 * device code).
 */
typedef uint8_t rc5_cmd_t;

/**
 * Initialize the rc5 hardware. 
 * 
 * This enables the timer used for waveform generation and its interrupt.
 */
void rc5_init(void);

/**
 * Send an rc5 telegram. 
 */
void rc5_send(rc5_cmd_t cmd);

/**
 * Callback function to notify the user that the last telegram has been sent and
 * the rc5 module is ready to send the next telegram.
 */
extern void rc5_on_send_complete(void);

/**
 * Callback function to notify the user that the last telegram has been sent. 
 *
 * A call of this function does not mean that the next telegram can be sent, but
 * only that the transmitter is now idle and waiting for the inter-telegram 
 * time to expire.
 */
extern void rc5_on_telegram_complete(void);
#endif // RC5_H