/* $Id: buttons.c 11 2009-10-14 06:21:07Z andreas $ */

/*
 * Copyright (c) 2006-2009 Andreas Schroeder <andreas@a-netz.de>
 *
 * Implement functions of an infrared remote control and RC5 protocol with an
 * Atmel AVR controller.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <avr/io.h>

#include "buttons.h"
#include "rc5_codes.h"

/*
 * Initialize the hardware to read the button states.
 *
 * Set the ports to input with pullups enabled.
 */
void buttons_init(void) {
  DDRD &= ~(_BV(PD0) | _BV(PD1) | _BV(PD2) | _BV(PD3) | _BV(PD4) | _BV(PD5));
  PORTD = _BV(PD0) | _BV(PD1) | _BV(PD2) | _BV(PD3) | _BV(PD4) | _BV(PD5);
}

/*
 * Callback function from the rc5 module. This reads in the current button 
 * state and returns the corresponding rc5 command code.
 */
uint8_t rc5_get_cmd(rc5_cmd_t *cmd) {
  uint8_t buttons = (~PIND) & (_BV(PD0) | _BV(PD1) | _BV(PD3) | _BV(PD4) | _BV(PD5));
  *cmd = 0xff;

  switch(buttons) {
  case _BV(PD0):
    *cmd = RC5_CMD_VOLUME_INC;
    break;
  case _BV(PD1):
    *cmd = RC5_CMD_VOLUME_DEC;
    break;
  case _BV(PD3):
    *cmd = RC5_CMD_PROGRAM_INC;
    break;
  case _BV(PD4):
    *cmd = RC5_CMD_PROGRAM_DEC;
    break;
  case _BV(PD5):
    *cmd = RC5_CMD_STANDBY;
    break;
  default:
    return 1;
  }
  
  return 0;
}