/* $Id: led.c 11 2009-10-14 06:21:07Z andreas $ */

/*
 * Copyright (c) 2006-2009 Andreas Schroeder <andreas@a-netz.de>
 *
 * Implement functions of an infrared remote control and RC5 protocol with an
 * Atmel AVR controller.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "led.h"

#include <avr/io.h>

/** LED port register */
#define LED_PORT PORTB
/** LED data direction register */
#define LED_DDR DDRB
/** LED bit */
#define LED_BIT PB6

/** Turn on the status led. */
#define LED_ON() LED_PORT &= ~_BV(LED_BIT);

/** Turn off the status led. */
#define LED_OFF() LED_PORT |= _BV(LED_BIT);

/*
 * Initialize the led hardware.
 */
void led_init(void) {
  LED_PORT |= _BV(LED_BIT);
  LED_DDR |= _BV(LED_BIT);
}


/*
 * Set the state of the led.
 */
void led_set(uint8_t state) {
  if(state) {
    LED_ON();
  } else {
    LED_OFF();
  }
}